/*
 * $Id: ReloadableDefinitionsFactory.java 669657 2008-06-19 19:05:51Z apetrelli $
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.tiles.definition;

/**
 * Indicates support for reloading Tiles configuration when it changes in {@link DefinitionsFactory}.
 *
 * @version $Rev: 669657 $ $Date: 2008-06-19 21:05:51 +0200 (gio, 19 giu 2008) $
 * @deprecated Use {@link Refreshable}.
 */
public interface ReloadableDefinitionsFactory extends Refreshable {
}
